@@ -115,7 +115,7 @@ typedef unsigned long guintptr;
 
 #define GLIB_MAJOR_VERSION 2
 #define GLIB_MINOR_VERSION 58
-#define GLIB_MICRO_VERSION 1
+#define GLIB_MICRO_VERSION 2
 
 #define G_OS_UNIX
 
@@ -138,7 +138,7 @@ typedef unsigned long guintptr;
 #  undef G_HAVE_ISO_VARARGS
 #endif
 
-#undef G_HAVE_GROWING_STACK
+#define G_HAVE_GROWING_STACK 0
 #define G_HAVE_GNUC_VISIBILITY 1
 
 #ifndef _MSC_VER
@@ -158,7 +158,7 @@ typedef unsigned long guintptr;
 #define G_THREADS_ENABLED
 #define G_THREADS_IMPL_POSIX
 
-#define G_ATOMIC_OP_MEMORY_BARRIER_NEEDED
+#undef G_ATOMIC_OP_MEMORY_BARRIER_NEEDED
 #define G_ATOMIC_LOCK_FREE
 
 #define GINT16_TO_LE(val)	((gint16) (val))
